<?php //$Id: mod_form.php,v 1.5 2011/01/25 11:55:14 pangard Exp $

/**
 * This file defines the main videotutor configuration form
 * It uses the standard core Moodle (>1.8) formslib. For
 * more info about them, please visit:
 *
 * http://docs.moodle.org/en/Development:lib/formslib.php
 *
 * The form must provide support for, at least these fields:
 *   - name: text element of 64cc max
 *
 * Also, it's usual to use these fields:
 *   - intro: one htmlarea element to describe the activity
 *            (will be showed in the list of activities of
 *             videotutor type (index.php) and in the header
 *             of the videotutor main page (view.php).
 *   - introformat: The format used to write the contents
 *             of the intro field. It automatically defaults
 *             to HTML when the htmleditor is used and can be
 *             manually selected if the htmleditor is not used
 *             (standard formats are: MOODLE, HTML, PLAIN, MARKDOWN)
 *             See lib/weblib.php Constants and the format_text()
 *             function for more info
 */

require_once($CFG->dirroot.'/course/moodleform_mod.php');

class mod_videotutor_mod_form extends moodleform_mod {

    function definition() {

        global $COURSE;
        $mform =& $this->_form;

//-------------------------------------------------------------------------------
    /// Adding the "general" fieldset, where all the common settings are showed
        $mform->addElement('header', 'general', get_string('general', 'form'));

    /// Adding the standard "name" field
        $mform->addElement('text', 'name', get_string('videotutorname', 'videotutor'), array('size'=>'64'));
        $mform->setType('name', PARAM_TEXT);
        $mform->addRule('name', null, 'required', null, 'client');
        $mform->addRule('name', get_string('maximumchars', '', 255), 'maxlength', 255, 'client');

    /// Adding the required "intro" field to hold the description of the instance
        $mform->addElement('htmleditor', 'intro', get_string('videotutorintro', 'videotutor'));
        $mform->setType('intro', PARAM_RAW);
        $mform->addRule('intro', get_string('required'), 'required', null, 'client');
        $mform->setHelpButton('intro', array('writing', 'richtext'), false, 'editorhelpbutton');

//-------------------------------------------------------------------------------
    /// Adding the rest of videotutor settings, spreeading all them into this fieldset
    /// or adding more fieldsets ('header' elements) if needed for better logic
        $mform->addElement('text', 'numdiap', get_string('numdiapos', 'videotutor'));
        $mform->addRule('numdiap', get_string('required'), 'required', null, 'numeric', null, 'client');

    /// Usar el jsmath que distribuimos con videotutor o no (por ej, para usar otro plugin)
    $vopciones=array();
    $vopciones[] =& HTML_QuickForm::createElement('radio', 'use_bundled_jsmath', null, 
                get_string('use_bundled_jsmath','videotutor'), 1);
    $vopciones[] =& HTML_QuickForm::createElement('radio', 'use_bundled_jsmath', null, 
                get_string('dont_use_bundled_jsmath','videotutor'), 0);
    $mform->addGroup($vopciones, 'use_bundled_jsmath', 
             get_string('use_bundled_jsmath?','videotutor') , '<br />', false);

    
//-------------------------------------------------------------------------------
        // add standard elements, common to all modules
        $this->standard_coursemodule_elements();
//-------------------------------------------------------------------------------
        // add standard buttons, common to all modules
        $this->add_action_buttons();

    }
}

?>
